import React from 'react';
import { View, BackHandler, Modal, TouchableOpacity } from 'react-native';
import AsyncStorage from '@react-native-async-storage/async-storage';
import CustomScrollView from 'muba-custom-scroll-view';
import OutputText from 'muba-output-text';
import { strings, loadLocaleData } from 'muba-i18n';
import { addFontList } from 'muba-font';
import { popupStyles } from './PopupStyles';
import { createIconSetFromFontello } from 'react-native-vector-icons';
import fontelloConfig from './fonts/config.json';
import Overlay from 'muba-popup-advice/Overlay';
const FontAwesomeIcon = createIconSetFromFontello(fontelloConfig);

export const ERROR_POPUP = 'errorPopup';

export default class PopupAdvice extends React.Component {
  constructor(props) {
    super(props);

    loadLocaleData({
      ar: require('./locales/ar.json'),
      en: require('./locales/en.json'),
      es: require('./locales/es.json'),
      fr: require('./locales/fr.json'),
      it: require('./locales/it.json'),
      nl: require('./locales/nl.json'),
    });

    this.state = ({
      visible: false,
      fontLoaded: false,
      icon: props.icon ? { ...props.icon, props: { style: [popupStyles.popupTitle, popupStyles.marginNeg, this.props.headerColor, this.props.iconStyle], ...props.icon ? props.icon.props : null } } : null
    });
  }

  async componentDidMount() {
    await addFontList([
      {
        name: 'PopupAdviceBold',
        source: require('./fonts/Poppins/Poppins-Bold.ttf')
      },
      {
        name: 'PopupAdviceSemiBold',
        source: require('./fonts/Poppins/Poppins-SemiBold.ttf')
      },
      {
        name: 'PopupAdviceRegular',
        source: require('./fonts/Poppins/Poppins-Regular.ttf')
      },
      {
        name: 'PopupAdviceFontAwesome',
        source: require('./fonts/Font-Awesome.ttf')
      }
    ]);
    this.setState({ fontLoaded: true });
  }

  componentDidUpdate = (prevProps) => {
    if (this.isVisible()) {
      BackHandler.addEventListener('hardwareBackPress', function () {
        if (this.state.visible) {
          this.hide();
          return true;
        }
      }.bind(this));
    }

    if (prevProps.icon !== this.props.icon) {
      this.setState({ icon: this.props.icon ? { ...this.props.icon, props: { style: [popupStyles.popupTitle, popupStyles.marginNeg, this.props.headerColor, this.props.iconStyle], ...this.props.icon ? this.props.icon.props : null } } : null });
    }
  }

  isVisible = async () => {
    return this.state.visible;
  }

  show = async () => {
    if (await AsyncStorage.getItem(ERROR_POPUP) !== 'true') {
      await this.setState({ visible: true });
    }
  }

  hide = async (submit) => {
    if (submit || this.props.closable !== false) {
      if (submit !== true && this.props.beforeClose) {
        await this.props.beforeClose();
      }
      await this.setState({ visible: false });
      if (submit !== true && this.props.onClose) {
        this.props.onClose();
      }
    }
  }

  submit = async () => {
    if (this.props.onSubmit && !this.props.disableSubmit) {
      if (await this.props.onSubmit()) {
        this.hide(true);
        if (this.props.afterSubmit) {
          this.props.afterSubmit();
        }
      }
    } else {
      this.hide(true);
    }
  }

  render() {
    return (
      this.state.fontLoaded ?
        <Modal
          animationType="none"
          transparent={true}
          visible={this.state.visible}
          onRequestClose={() => {
            this.setState({ visible: false });
            if (this.props.onRequestClose) { this.props.onRequestClose() };
          }}>
          <View style={[popupStyles.containerStyle, this.props.containerStyle]}>
            <Overlay onPress={() => { if (this.props.closeButton !== false) this.hide(false) }} />
            <View style={[popupStyles.popupBox, this.props.dialogStyle]}>
              {this.props.closable === false || this.props.closeButton === false ?
                <View />
                :
                <TouchableOpacity style={popupStyles.popupCloseButton} onPress={() => this.hide(false)} activeOpacity={0.6}>
                  {this.state.fontLoaded ?
                    <FontAwesomeIcon style={[popupStyles.greyText, popupStyles.popupCloseIcon, this.props.closeOnLeft ? popupStyles.popupCloseIconLeft : null]} name='close-popup-advice' />
                    :
                    null
                  }
                </TouchableOpacity>
              }
              {this.props.children ?
                <CustomScrollView ref={(element) => this.scroll = element} style={[popupStyles.scrollStyle, this.props.scrollStyle]}>
                  <View style={popupStyles.popupScrollContainer}>
                    {this.props.title || this.props.icon ?
                      <View style={popupStyles.alignCenter}>
                        <OutputText style={[popupStyles.popupTitle, this.props.headerColor]}>{this.props.icon ? this.state.icon : null} {this.props.title}</OutputText>
                      </View>
                      :
                      null
                    }

                    {this.props.children}
                    {this.props.hideButton ?
                      <View />
                      :
                      <TouchableOpacity style={[popupStyles.okBtnBox, this.props.buttonColor ? this.props.buttonColor : popupStyles.okBtn,]} onPress={this.submit} >
                        {this.props.textButton && !this.props.disableSubmit ?
                          <OutputText style={popupStyles.okBtnText}>{this.props.textButton}</OutputText>
                          :
                          <OutputText style={popupStyles.okBtnText}>{strings('adviceOK').toUpperCase()}</OutputText>
                        }
                      </TouchableOpacity>
                    }
                  </View>
                </CustomScrollView>
                :
                <View />
              }
              {this.props.outsideScroll}
            </View>
          </View>
        </Modal >
        :
        <View />
    );
  }
}